@@ -27,12 +27,13 @@ __all__ = [
     'TRANSPORT_ALIASES',
 ]
 
-from oslo.config import cfg
 from oslo import messaging
+from oslo_config import cfg
+from oslo_serialization import jsonutils
 
 from ironic.common import context as ironic_context
 from ironic.common import exception
-from ironic.openstack.common import jsonutils
+
 
 CONF = cfg.CONF
 TRANSPORT = None
